<?php

namespace SimpleSAML\Error;

/**
 * Class NoPassive
 *
 * @deprecated This class has been deprecated and will be removed in SimpleSAMLphp 2.0. Please use
 * \SimpleSAML\Module\saml\Error\NoPassive instead.
 *
 * @see \SimpleSAML\Module\saml\Error\NoPassive
 */

class NoPassive extends Exception
{
}
